@@ -10,7 +10,7 @@ use crate::{
     irust::format::{format_check_output, format_err, format_eval_output},
     utils::ctrlc_cancel,
 };
-use irust_repl::{cargo_cmds::*, EvalConfig, EvalResult, Executor, ToolChain};
+use irust_repl::{cargo_cmds::*, EvalConfig, EvalResult, Executor, MainResult, ToolChain};
 use printer::printer::{PrintQueue, PrinterItem};
 
 const SUCCESS: &str = "Ok!";
@@ -61,6 +61,7 @@ impl IRust {
             cmd if cmd.starts_with(":cd") => self.cd(),
             cmd if cmd.starts_with(":color") => self.color(),
             cmd if cmd.starts_with(":toolchain") => self.toolchain(),
+            cmd if cmd.starts_with(":main_result") => self.main_result(),
             cmd if cmd.starts_with(":check_statements") => self.check_statements(),
             cmd if cmd.starts_with(":time_release") => self.time_release(),
             cmd if cmd.starts_with(":time") => self.time(),
@@ -118,6 +119,20 @@ impl IRust {
         }
     }
 
+    fn main_result(&mut self) -> Result<PrintQueue> {
+        let buffer = self.buffer.to_string();
+        let main_result = buffer.split_whitespace().nth(1);
+
+        if let Some(main_result) = main_result {
+            let main_result = MainResult::from_str(main_result)?;
+            self.repl.set_main_result(main_result);
+            self.options.main_result = main_result;
+            success!()
+        } else {
+            print_queue!(self.options.main_result.to_string(), Color::Blue)
+        }
+    }
+
     fn add_dep(&mut self) -> Result<PrintQueue> {
         let mut dep: Vec<String> = crate::utils::split_args(self.buffer.to_string());
         dep.remove(0); //drop :add
@@ -262,8 +277,9 @@ impl IRust {
         let mut raw_out = String::new();
 
         let toolchain = self.options.toolchain;
-        self.repl.eval_in_tmp_repl(variable, || -> Result<()> {
-            let (_status, out) = cargo_run(false, false, toolchain, Some(ctrlc_cancel))?;
+        let get_type = format!("let _:() = {};", variable);
+        self.repl.eval_in_tmp_repl(get_type, || -> Result<()> {
+            let (_status, out) = cargo_build_output(false, false, toolchain)?;
             raw_out = out;
             Ok(())
         })?;
@@ -607,6 +623,7 @@ impl IRust {
             return success!();
         }
 
+        // Sanity checks
         // set
         if !evaluator.contains("$$") {
             return Err(
@@ -614,6 +631,10 @@ impl IRust {
                     .into(),
             );
         }
+        if !evaluator.ends_with(';') {
+            return Err("evaluator must end with ;".into());
+        }
+
         let evaluator: Vec<String> = evaluator.split("$$").map(ToOwned::to_owned).collect();
         if evaluator.len() != 2 {
             return Err("evaluator requires two parts".into());
